diff --git a/doc/Plugins.md b/doc/Plugins.md
index 24d403e1f..a30a3f4a7 100644
--- a/doc/Plugins.md
+++ b/doc/Plugins.md
@@ -1,5 +1,7 @@
Friendica Addon/Plugin development
-==========================
+==============
+
+* [Home](help)
Please see the sample addon 'randplace' for a working example of using some of these features.
Addons work by intercepting event hooks - which must be registered.
@@ -16,12 +18,12 @@ Future extensions may provide for "setup" amd "remove".
Plugins should contain a comment block with the four following parameters:
- /*
- * Name: My Great Plugin
- * Description: This is what my plugin does. It's really cool
- * Version: 1.0
- * Author: John Q. Public
- */
+ /*
+ * Name: My Great Plugin
+ * Description: This is what my plugin does. It's really cool.
+ * Version: 1.0
+ * Author: John Q. Public
+ */
Register your plugin hooks during installation.
@@ -45,7 +47,7 @@ Your hook callback functions will be called with at least one and possibly two a
If you wish to make changes to the calling data, you must declare them as reference variables (with '&') during function declaration.
-###$a
+#### $a
$a is the Friendica 'App' class.
It contains a wealth of information about the current state of Friendica:
@@ -56,13 +58,13 @@ It contains a wealth of information about the current state of Friendica:
It is recommeded you call this '$a' to match its usage elsewhere.
-###$b
+#### $b
$b can be called anything you like.
This is information specific to the hook currently being processed, and generally contains information that is being immediately processed or acted on that you can use, display, or alter.
Remember to declare it with '&' if you wish to alter it.
Modules
---------
+---
Plugins/addons may also act as "modules" and intercept all page requests for a given URL path.
In order for a plugin to act as a module it needs to define a function "plugin_name_module()" which takes no arguments and needs not do anything.
@@ -72,15 +74,15 @@ These are parsed into an array $a->argv, with a corresponding $a->argc indicatin
So http://my.web.site/plugin/arg1/arg2 would look for a module named "plugin" and pass its module functions the $a App structure (which is available to many components).
This will include:
- $a->argc = 3
- $a->argv = array(0 => 'plugin', 1 => 'arg1', 2 => 'arg2');
+ $a->argc = 3
+ $a->argv = array(0 => 'plugin', 1 => 'arg1', 2 => 'arg2');
Your module functions will often contain the function plugin_name_content(&$a), which defines and returns the page body content.
They may also contain plugin_name_post(&$a) which is called before the _content function and typically handles the results of POST forms.
You may also have plugin_name_init(&$a) which is called very early on and often does module initialisation.
Templates
-----------
+---
If your plugin needs some template, you can use the Friendica template system.
Friendica uses [smarty3](http://www.smarty.net/) as a template engine.
@@ -104,140 +106,140 @@ See also the wiki page [Quick Template Guide](https://github.com/friendica/frien
Current hooks
-------------
-###'authenticate'
+### 'authenticate'
'authenticate' is called when a user attempts to login.
$b is an array containing:
- 'username' => the supplied username
- 'password' => the supplied password
+ 'username' => the supplied username
+ 'password' => the supplied password
'authenticated' => set this to non-zero to authenticate the user.
'user_record' => successful authentication must also return a valid user record from the database
-###'logged_in'
+### 'logged_in'
'logged_in' is called after a user has successfully logged in.
$b contains the $a->user array.
-###'display_item'
+### 'display_item'
'display_item' is called when formatting a post for display.
$b is an array:
'item' => The item (array) details pulled from the database
'output' => the (string) HTML representation of this item prior to adding it to the page
-###'post_local'
+### 'post_local'
* called when a status post or comment is entered on the local system
* $b is the item array of the information to be stored in the database
* Please note: body contents are bbcode - not HTML
-###'post_local_end'
+### 'post_local_end'
* called when a local status post or comment has been stored on the local system
* $b is the item array of the information which has just been stored in the database
* Please note: body contents are bbcode - not HTML
-###'post_remote'
+### 'post_remote'
* called when receiving a post from another source. This may also be used to post local activity or system generated messages.
* $b is the item array of information to be stored in the database and the item body is bbcode.
-###'settings_form'
+### 'settings_form'
* called when generating the HTML for the user Settings page
* $b is the (string) HTML of the settings page before the final '' tag.
-###'settings_post'
+### 'settings_post'
* called when the Settings pages are submitted
* $b is the $_POST array
-###'plugin_settings'
+### 'plugin_settings'
* called when generating the HTML for the addon settings page
* $b is the (string) HTML of the addon settings page before the final '' tag.
-###'plugin_settings_post'
+### 'plugin_settings_post'
* called when the Addon Settings pages are submitted
* $b is the $_POST array
-###'profile_post'
+### 'profile_post'
* called when posting a profile page
* $b is the $_POST array
-###'profile_edit'
+### 'profile_edit'
'profile_edit' is called prior to output of profile edit page.
$b is an array containing:
'profile' => profile (array) record from the database
'entry' => the (string) HTML of the generated entry
-###'profile_advanced'
+### 'profile_advanced'
* called when the HTML is generated for the 'Advanced profile', corresponding to the 'Profile' tab within a person's profile page
* $b is the (string) HTML representation of the generated profile
* The profile array details are in $a->profile.
-###'directory_item'
+### 'directory_item'
'directory_item' is called from the Directory page when formatting an item for display.
$b is an array:
'contact' => contact (array) record for the person from the database
'entry' => the (string) HTML of the generated entry
-###'profile_sidebar_enter'
+### 'profile_sidebar_enter'
* called prior to generating the sidebar "short" profile for a page
* $b is the person's profile array
-###'profile_sidebar'
+### 'profile_sidebar'
'profile_sidebar is called when generating the sidebar "short" profile for a page.
$b is an array:
'profile' => profile (array) record for the person from the database
'entry' => the (string) HTML of the generated entry
-###'contact_block_end'
+### 'contact_block_end'
is called when formatting the block of contacts/friends on a profile sidebar has completed.
$b is an array:
'contacts' => array of contacts
'output' => the (string) generated HTML of the contact block
-###'bbcode'
+### 'bbcode'
* called during conversion of bbcode to html
* $b is a string converted text
-###'html2bbcode'
+### 'html2bbcode'
* called during conversion of html to bbcode (e.g. remote message posting)
* $b is a string converted text
-###'page_header'
+### 'page_header'
* called after building the page navigation section
* $b is a string HTML of nav region
-###'personal_xrd'
+### 'personal_xrd'
'personal_xrd' is called prior to output of personal XRD file.
$b is an array:
'user' => the user record for the person
'xml' => the complete XML to be output
-###'home_content'
+### 'home_content'
* called prior to output home page content, shown to unlogged users
* $b is (string) HTML of section region
-###'contact_edit'
+### 'contact_edit'
is called when editing contact details on an individual from the Contacts page.
$b is an array:
'contact' => contact record (array) of target contact
'output' => the (string) generated HTML of the contact edit page
-###'contact_edit_post'
+### 'contact_edit_post'
* called when posting the contact edit page.
* $b is the $_POST array
-###'init_1'
+### 'init_1'
* called just after DB has been opened and before session start
* $b is not used or passed
-###'page_end'
+### 'page_end'
* called after HTML content functions have completed
* $b is (string) HTML of content div
-###'avatar_lookup'
+### 'avatar_lookup'
'avatar_lookup' is called when looking up the avatar.
$b is an array:
@@ -245,11 +247,11 @@ $b is an array:
'email' => email to look up the avatar for
'url' => the (string) generated URL of the avatar
-###'emailer_send_prepare'
+### 'emailer_send_prepare'
'emailer_send_prepare' called from Emailer::send() before building the mime message.
$b is an array, params to Emailer::send()
- 'fromName' => name of the sender
+ 'fromName' => name of the sender
'fromEmail' => email fo the sender
'replyTo' => replyTo address to direct responses
'toEmail' => destination email address
@@ -258,20 +260,20 @@ $b is an array, params to Emailer::send()
'textVersion' => text only version of the message
'additionalMailHeader' => additions to the smtp mail header
-###'emailer_send'
+### 'emailer_send'
is called before calling PHP's mail().
$b is an array, params to mail()
- 'to'
- 'subject'
+ 'to'
+ 'subject'
'body'
'headers'
-###'nav_info'
+### 'nav_info'
is called after the navigational menu is build in include/nav.php.
$b is an array containing $nav from nav.php.
-###'template_vars'
+### 'template_vars'
is called before vars are passed to the template engine to render the page.
The registered function can add,change or remove variables passed to template.
$b is an array with:
@@ -463,4 +465,3 @@ mod/cb.php: call_hooks('cb_afterpost');
mod/cb.php: call_hooks('cb_content', $o);
mod/directory.php: call_hooks('directory_item', $arr);
-
diff --git a/doc/de/Plugins.md b/doc/de/Plugins.md
index dcff41a4b..40be4a069 100644
--- a/doc/de/Plugins.md
+++ b/doc/de/Plugins.md
@@ -1,27 +1,28 @@
-**Friendica Addon/Plugin-Entwicklung**
+Friendica Addon/Plugin-Entwicklung
==============
* [Zur Startseite der Hilfe](help)
-Bitte schau dir das Beispiel-Addon "randplace" für ein funktionierendes Beispiel für manche der hier aufgeführten Funktionen an.
-Das Facebook-Addon bietet ein Beispiel dafür, die "addon"- und "module"-Funktion gemeinsam zu integrieren.
-Addons arbeiten, indem sie Event Hooks abfangen. Module arbeiten, indem bestimmte Seitenanfragen (durch den URL-Pfad) abgefangen werden
+Bitte schau dir das Beispiel-Addon "randplace" für ein funktionierendes Beispiel für manche der hier aufgeführten Funktionen an.
+Das Facebook-Addon bietet ein Beispiel dafür, die "addon"- und "module"-Funktion gemeinsam zu integrieren.
+Addons arbeiten, indem sie Event Hooks abfangen.
+Module arbeiten, indem bestimmte Seitenanfragen (durch den URL-Pfad) abgefangen werden.
-Plugin-Namen können keine Leerstellen oder andere Interpunktionen enthalten und werden als Datei- und Funktionsnamen genutzt.
-Du kannst einen lesbaren Namen im Kommentarblock eintragen.
-Jedes Addon muss beides beinhalten - eine Installations- und eine Deinstallationsfunktion, die auf dem Addon-/Plugin-Namen basieren; z.B. "plugin1name_install()".
-Diese beiden Funktionen haben keine Argumente und sind dafür verantwortlich, Event Hooks zu registrieren und abzumelden (unregistering), die dein Plugin benötigt.
-Die Installations- und Deinstallationsfunktionfunktionen werden auch ausgeführt (z.B. neu installiert), wenn sich das Plugin nach der Installation ändert - somit sollte deine Deinstallationsfunktion keine Daten zerstört und deine Installationsfunktion sollte bestehende Daten berücksichtigen.
+Plugin-Namen können keine Leerstellen oder andere Interpunktionen enthalten und werden als Datei- und Funktionsnamen genutzt.
+Du kannst einen lesbaren Namen im Kommentarblock eintragen.
+Jedes Addon muss beides beinhalten - eine Installations- und eine Deinstallationsfunktion, die auf dem Addon-/Plugin-Namen basieren; z.B. "plugin1name_install()".
+Diese beiden Funktionen haben keine Argumente und sind dafür verantwortlich, Event Hooks zu registrieren und abzumelden (unregistering), die dein Plugin benötigt.
+Die Installations- und Deinstallationsfunktionfunktionen werden auch ausgeführt (z.B. neu installiert), wenn sich das Plugin nach der Installation ändert - somit sollte deine Deinstallationsfunktion keine Daten zerstört und deine Installationsfunktion sollte bestehende Daten berücksichtigen.
Zukünftige Extensions werden möglicherweise "Setup" und "Entfernen" anbieten.
Plugins sollten einen Kommentarblock mit den folgenden vier Parametern enthalten:
- /*
- * Name: My Great Plugin
- * Description: This is what my plugin does. It's really cool
- * Version: 1.0
- * Author: John Q. Public
- */
+ /*
+ * Name: My Great Plugin
+ * Description: This is what my plugin does. It's really cool.
+ * Version: 1.0
+ * Author: John Q. Public
+ */
Registriere deine Plugin-Hooks während der Installation.
@@ -29,45 +30,50 @@ Registriere deine Plugin-Hooks während der Installation.
$hookname ist ein String und entspricht einem bekannten Friendica-Hook.
-$file steht für den Pfadnamen, der relativ zum Top-Level-Friendicaverzeichnis liegt.
+$file steht für den Pfadnamen, der relativ zum Top-Level-Friendicaverzeichnis liegt.
Das *sollte* "addon/plugin_name/plugin_name.php' sein.
$function ist ein String und der Name der Funktion, die ausgeführt wird, wenn der Hook aufgerufen wird.
+Argumente
+---
+
Deine Hook-Callback-Funktion wird mit mindestens einem und bis zu zwei Argumenten aufgerufen
function myhook_function(&$a, &$b) {
}
-Wenn du Änderungen an den aufgerufenen Daten vornehmen willst, musst du diese als Referenzvariable (mit "&") während der Funktionsdeklaration deklarieren.
+Wenn du Änderungen an den aufgerufenen Daten vornehmen willst, musst du diese als Referenzvariable (mit "&") während der Funktionsdeklaration deklarieren.
-$a ist die Friendica "App"-Klasse, die eine Menge an Informationen über den aktuellen Friendica-Status beinhaltet, u.a. welche Module genutzt werden, Konfigurationsinformationen, Inhalte der Seite zum Zeitpunkt des Hook-Aufrufs.
-Es ist empfohlen, diese Funktion "$a" zu nennen, um seine Nutzung an den Gebrauch an anderer Stelle anzugleichen.
+$a ist die Friendica "App"-Klasse, die eine Menge an Informationen über den aktuellen Friendica-Status beinhaltet, u.a. welche Module genutzt werden, Konfigurationsinformationen, Inhalte der Seite zum Zeitpunkt des Hook-Aufrufs.
+Es ist empfohlen, diese Funktion "$a" zu nennen, um seine Nutzung an den Gebrauch an anderer Stelle anzugleichen.
-$b kann frei benannt werden.
-Diese Information ist speziell auf den Hook bezogen, der aktuell bearbeitet wird, und beinhaltet normalerweise Daten, die du sofort nutzen, anzeigen oder bearbeiten kannst.
-Achte darauf, diese mit "&" zu deklarieren, wenn du sie bearbeiten willst.
+$b kann frei benannt werden.
+Diese Information ist speziell auf den Hook bezogen, der aktuell bearbeitet wird, und beinhaltet normalerweise Daten, die du sofort nutzen, anzeigen oder bearbeiten kannst.
+Achte darauf, diese mit "&" zu deklarieren, wenn du sie bearbeiten willst.
-**Module**
+Module
+---
-Plugins/Addons können auch als "Module" agieren und alle Seitenanfragen für eine bestimte URL abfangen.
-Um ein Plugin als Modul zu nutzen, ist es nötig, die Funktion "plugin_name_module()" zu definieren, die keine Argumente benötigt und nichts weiter machen muss.
+Plugins/Addons können auch als "Module" agieren und alle Seitenanfragen für eine bestimte URL abfangen.
+Um ein Plugin als Modul zu nutzen, ist es nötig, die Funktion "plugin_name_module()" zu definieren, die keine Argumente benötigt und nichts weiter machen muss.
-Wenn diese Funktion existiert, wirst du nun alle Seitenanfragen für "http://my.web.site/plugin_name" erhalten - mit allen URL-Komponenten als zusätzliche Argumente.
-Diese werden in ein Array $a->argv geparst und stimmen mit $a->argc überein, wobei sie die Anzahl der URL-Komponenten abbilden.
-So würde http://my.web.site/plugin/arg1/arg2 nach einem Modul "plugin" suchen und seiner Modulfunktion die $a-App-Strukur übergeben (dies ist für viele Komponenten verfügbar). Das umfasst:
+Wenn diese Funktion existiert, wirst du nun alle Seitenanfragen für "http://example.com/plugin_name" erhalten - mit allen URL-Komponenten als zusätzliche Argumente.
+Diese werden in ein Array $a->argv geparst und stimmen mit $a->argc überein, wobei sie die Anzahl der URL-Komponenten abbilden.
+So würde http://example.com/plugin/arg1/arg2 nach einem Modul "plugin" suchen und seiner Modulfunktion die $a-App-Strukur übergeben (dies ist für viele Komponenten verfügbar). Das umfasst:
- $a->argc = 3
- $a->argv = array(0 => 'plugin', 1 => 'arg1', 2 => 'arg2');
+ $a->argc = 3
+ $a->argv = array(0 => 'plugin', 1 => 'arg1', 2 => 'arg2');
-Deine Modulfunktionen umfassen oft die Funktion plugin_name_content(&$a), welche den Seiteninhalt definiert und zurückgibt.
-Sie können auch plugin_name_post(&$a) umfassen, welches vor der content-Funktion aufgerufen wird und normalerweise die Resultate der POST-Formulare handhabt.
+Deine Modulfunktionen umfassen oft die Funktion plugin_name_content(&$a), welche den Seiteninhalt definiert und zurückgibt.
+Sie können auch plugin_name_post(&$a) umfassen, welches vor der content-Funktion aufgerufen wird und normalerweise die Resultate der POST-Formulare handhabt.
Du kannst ebenso plugin_name_init(&$a) nutzen, was oft frühzeitig aufgerufen wird und das Modul initialisert.
-**Derzeitige Hooks:**
+Derzeitige Hooks
+---
**'authenticate'** - wird aufgerufen, wenn sich der User einloggt.
$b ist ein Array
@@ -180,6 +186,9 @@ Du kannst ebenso plugin_name_init(&$a) nutzen, was oft frühzeitig aufgerufen wi
- wird aufgerufen nachdem in include/nav,php der Inhalt des Navigations Menüs erzeugt wurde.
- $b ist ein Array, das $nav wiederspiegelt.
+Komplette Liste der Hook-Callbacks
+---
+
Eine komplette Liste aller Hook-Callbacks mit den zugehörigen Dateien (am 14-Feb-2012 generiert): Bitte schau in die Quellcodes für Details zu Hooks, die oben nicht dokumentiert sind.
boot.php: call_hooks('login_hook',$o);
@@ -204,7 +213,7 @@ include/text.php: call_hooks('contact_block_end', $arr);
include/text.php: call_hooks('smilie', $s);
-include/text.php: call_hooks('prepare_body_init', $item);
+include/text.php: call_hooks('prepare_body_init', $item);
include/text.php: call_hooks('prepare_body', $prep_arr);
@@ -359,4 +368,3 @@ mod/cb.php: call_hooks('cb_afterpost');
mod/cb.php: call_hooks('cb_content', $o);
mod/directory.php: call_hooks('directory_item', $arr);
-
diff --git a/doc/themes.md b/doc/themes.md
index add44c776..ec3a76ac2 100644
--- a/doc/themes.md
+++ b/doc/themes.md
@@ -59,7 +59,19 @@ The same rule applies to the JavaScript files found in
they will be overwritten by files in
- /view/theme/**your-theme-name**/js.
+ /view/theme/**your-theme-name**/js
+
+### Modules
+
+You have the freedom to override core modules found in
+
+ /mod
+
+They will be overwritten by files in
+
+ /view/theme/**your-theme-name**/mod
+
+Be aware that you can break things easily here if you don't know what you do. Also notice that you can override parts of the module – functions not defined in your theme module will be loaded from the core module.
## Expand an existing Theme
@@ -288,4 +300,4 @@ The default file is in
/view/default.php
if you want to change it, say adding a 4th column for banners of your favourite FLOSS projects, place a new default.php file in your theme directory.
-As with the theme.php file, you can use the properties of the $a variable with holds the friendica application to decide what content is displayed.
\ No newline at end of file
+As with the theme.php file, you can use the properties of the $a variable with holds the friendica application to decide what content is displayed.
diff --git a/mod/_well_known.php b/mod/_well_known.php
index 33070a1ec..6c33136f9 100644
--- a/mod/_well_known.php
+++ b/mod/_well_known.php
@@ -2,6 +2,7 @@
require_once("mod/hostxrd.php");
require_once("mod/nodeinfo.php");
+if(! function_exists('_well_known_init')) {
function _well_known_init(&$a){
if ($a->argc > 1) {
switch($a->argv[1]) {
@@ -19,7 +20,9 @@ function _well_known_init(&$a){
http_status_exit(404);
killme();
}
+}
+if(! function_exists('wk_social_relay')) {
function wk_social_relay(&$a) {
define('SR_SCOPE_ALL', 'all');
@@ -64,3 +67,4 @@ function wk_social_relay(&$a) {
echo json_encode($relay, JSON_PRETTY_PRINT|JSON_UNESCAPED_SLASHES);
exit;
}
+}
diff --git a/mod/acctlink.php b/mod/acctlink.php
index a2365803a..a551e3dbd 100644
--- a/mod/acctlink.php
+++ b/mod/acctlink.php
@@ -2,8 +2,8 @@
require_once('include/Scrape.php');
+if(! function_exists('acctlink_init')) {
function acctlink_init(&$a) {
-
if(x($_GET,'addr')) {
$addr = trim($_GET['addr']);
$res = probe_url($addr);
@@ -14,3 +14,4 @@ function acctlink_init(&$a) {
}
}
}
+}
diff --git a/mod/acl.php b/mod/acl.php
index f5e04b96a..5666ccabb 100644
--- a/mod/acl.php
+++ b/mod/acl.php
@@ -3,8 +3,8 @@
require_once("include/acl_selectors.php");
+if(! function_exists('acl_init')) {
function acl_init(&$a){
acl_lookup($a);
}
-
-
+}
diff --git a/mod/admin.php b/mod/admin.php
index 7f9000807..ff17c0b8c 100644
--- a/mod/admin.php
+++ b/mod/admin.php
@@ -2,7 +2,7 @@
/**
* @file mod/admin.php
- *
+ *
* @brief Friendica admin
*/
@@ -23,6 +23,7 @@ require_once("include/text.php");
* @param App $a
*
*/
+if(! function_exists('admin_post')) {
function admin_post(&$a){
@@ -110,6 +111,7 @@ function admin_post(&$a){
goaway($a->get_baseurl(true) . '/admin' );
return; // NOTREACHED
}
+}
/**
* @brief Generates content of the admin panel pages
@@ -128,6 +130,7 @@ function admin_post(&$a){
* @param App $a
* @return string
*/
+if(! function_exists('admin_content')) {
function admin_content(&$a) {
if(!is_site_admin()) {
@@ -245,6 +248,7 @@ function admin_content(&$a) {
return $o;
}
}
+}
/**
* @brief Subpage with some stats about "the federation" network
@@ -260,6 +264,7 @@ function admin_content(&$a) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_federation')) {
function admin_page_federation(&$a) {
// get counts on active friendica, diaspora, redmatrix, hubzilla, gnu
// social and statusnet nodes this node is knowing
@@ -284,7 +289,7 @@ function admin_page_federation(&$a) {
// what versions for that platform do we know at all?
// again only the active nodes
$v = q('SELECT count(*) AS total, version FROM gserver
- WHERE last_contact > last_failure AND platform LIKE "%s"
+ WHERE last_contact > last_failure AND platform LIKE "%s"
GROUP BY version
ORDER BY version;', $p);
@@ -301,12 +306,12 @@ function admin_page_federation(&$a) {
$newVC = $vv['total'];
$newVV = $vv['version'];
$posDash = strpos($newVV, '-');
- if($posDash)
+ if($posDash)
$newVV = substr($newVV, 0, $posDash);
if(isset($newV[$newVV]))
- $newV[$newVV] += $newVC;
+ $newV[$newVV] += $newVC;
else
- $newV[$newVV] = $newVC;
+ $newV[$newVV] = $newVC;
}
foreach ($newV as $key => $value) {
array_push($newVv, array('total'=>$value, 'version'=>$key));
@@ -361,6 +366,7 @@ function admin_page_federation(&$a) {
'$baseurl' => $a->get_baseurl(),
));
}
+}
/**
* @brief Admin Inspect Queue Page
@@ -375,6 +381,7 @@ function admin_page_federation(&$a) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_queue')) {
function admin_page_queue(&$a) {
// get content from the queue table
$r = q("SELECT c.name,c.nurl,q.id,q.network,q.created,q.last from queue as q, contact as c where c.id=q.cid order by q.cid, q.created;");
@@ -394,6 +401,7 @@ function admin_page_queue(&$a) {
'$entries' => $r,
));
}
+}
/**
* @brief Admin Summary Page
@@ -406,6 +414,7 @@ function admin_page_queue(&$a) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_summary')) {
function admin_page_summary(&$a) {
$r = q("SELECT `page-flags`, COUNT(uid) as `count` FROM `user` GROUP BY `page-flags`");
$accounts = array(
@@ -452,12 +461,14 @@ function admin_page_summary(&$a) {
'$plugins' => array( t('Active plugins'), $a->plugins )
));
}
+}
/**
* @brief Process send data from Admin Site Page
- *
+ *
* @param App $a
*/
+if(! function_exists('admin_page_site_post')) {
function admin_page_site_post(&$a) {
if(!x($_POST,"page_site")) {
return;
@@ -770,6 +781,7 @@ function admin_page_site_post(&$a) {
return; // NOTREACHED
}
+}
/**
* @brief Generate Admin Site subpage
@@ -779,6 +791,7 @@ function admin_page_site_post(&$a) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_site')) {
function admin_page_site(&$a) {
/* Installed langs */
@@ -983,7 +996,7 @@ function admin_page_site(&$a) {
'$form_security_token' => get_form_security_token("admin_site")
));
-
+}
}
/**
@@ -998,6 +1011,7 @@ function admin_page_site(&$a) {
* @param App $a
* @return string
**/
+if(! function_exists('admin_page_dbsync')) {
function admin_page_dbsync(&$a) {
$o = '';
@@ -1073,14 +1087,15 @@ function admin_page_dbsync(&$a) {
}
return $o;
-
+}
}
/**
* @brief Process data send by Users admin page
- *
+ *
* @param App $a
*/
+if(! function_exists('admin_page_users_post')) {
function admin_page_users_post(&$a){
$pending = ( x($_POST, 'pending') ? $_POST['pending'] : array() );
$users = ( x($_POST, 'user') ? $_POST['user'] : array() );
@@ -1171,6 +1186,7 @@ function admin_page_users_post(&$a){
goaway($a->get_baseurl(true) . '/admin/users' );
return; // NOTREACHED
}
+}
/**
* @brief Admin panel subpage for User management
@@ -1184,6 +1200,7 @@ function admin_page_users_post(&$a){
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_users')) {
function admin_page_users(&$a){
if($a->argc>2) {
$uid = $a->argv[3];
@@ -1336,7 +1353,7 @@ function admin_page_users(&$a){
$o .= paginate($a);
return $o;
}
-
+}
/**
* @brief Plugins admin page
@@ -1354,6 +1371,7 @@ function admin_page_users(&$a){
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_plugins')) {
function admin_page_plugins(&$a){
/*
@@ -1479,17 +1497,19 @@ function admin_page_plugins(&$a){
'$baseurl' => $a->get_baseurl(true),
'$function' => 'plugins',
'$plugins' => $plugins,
- '$pcount' => count($plugins),
+ '$pcount' => count($plugins),
'$noplugshint' => sprintf( t('There are currently no plugins available on your node. You can find the official plugin repository at %1$s and might find other interesting plugins in the open plugin registry at %2$s'), 'https://github.com/friendica/friendica-addons', 'http://addons.friendi.ca'),
'$form_security_token' => get_form_security_token("admin_themes"),
));
}
+}
/**
* @param array $themes
* @param string $th
* @param int $result
*/
+if(! function_exists('toggle_theme')) {
function toggle_theme(&$themes,$th,&$result) {
for($x = 0; $x < count($themes); $x ++) {
if($themes[$x]['name'] === $th) {
@@ -1504,12 +1524,14 @@ function toggle_theme(&$themes,$th,&$result) {
}
}
}
+}
/**
* @param array $themes
* @param string $th
* @return int
*/
+if(! function_exists('theme_status')) {
function theme_status($themes,$th) {
for($x = 0; $x < count($themes); $x ++) {
if($themes[$x]['name'] === $th) {
@@ -1523,12 +1545,13 @@ function theme_status($themes,$th) {
}
return 0;
}
-
+}
/**
* @param array $themes
* @return string
*/
+if(! function_exists('rebuild_theme_table')) {
function rebuild_theme_table($themes) {
$o = '';
if(count($themes)) {
@@ -1542,7 +1565,7 @@ function rebuild_theme_table($themes) {
}
return $o;
}
-
+}
/**
* @brief Themes admin page
@@ -1560,6 +1583,7 @@ function rebuild_theme_table($themes) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_themes')) {
function admin_page_themes(&$a){
$allowed_themes_str = get_config('system','allowed_themes');
@@ -1734,13 +1758,14 @@ function admin_page_themes(&$a){
'$form_security_token' => get_form_security_token("admin_themes"),
));
}
-
+}
/**
* @brief Prosesses data send by Logs admin page
- *
+ *
* @param App $a
*/
+if(! function_exists('admin_page_logs_post')) {
function admin_page_logs_post(&$a) {
if(x($_POST,"page_logs")) {
check_form_security_token_redirectOnErr('/admin/logs', 'admin_logs');
@@ -1758,6 +1783,7 @@ function admin_page_logs_post(&$a) {
goaway($a->get_baseurl(true) . '/admin/logs' );
return; // NOTREACHED
}
+}
/**
* @brief Generates admin panel subpage for configuration of the logs
@@ -1775,6 +1801,7 @@ function admin_page_logs_post(&$a) {
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_logs')) {
function admin_page_logs(&$a){
$log_choices = array(
@@ -1806,6 +1833,7 @@ function admin_page_logs(&$a){
'$phplogcode' => "error_reporting(E_ERROR | E_WARNING | E_PARSE );\nini_set('error_log','php.out');\nini_set('log_errors','1');\nini_set('display_errors', '1');",
));
}
+}
/**
* @brief Generates admin panel subpage to view the Friendica log
@@ -1825,6 +1853,7 @@ function admin_page_logs(&$a){
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_viewlogs')) {
function admin_page_viewlogs(&$a){
$t = get_markup_template("admin_viewlogs.tpl");
$f = get_config('system','logfile');
@@ -1861,12 +1890,14 @@ function admin_page_viewlogs(&$a){
'$logname' => get_config('system','logfile')
));
}
+}
/**
* @brief Prosesses data send by the features admin page
- *
+ *
* @param App $a
*/
+if(! function_exists('admin_page_features_post')) {
function admin_page_features_post(&$a) {
check_form_security_token_redirectOnErr('/admin/features', 'admin_manage_features');
@@ -1898,23 +1929,25 @@ function admin_page_features_post(&$a) {
goaway($a->get_baseurl(true) . '/admin/features' );
return; // NOTREACHED
}
+}
/**
* @brief Subpage for global additional feature management
- *
+ *
* This functin generates the subpage 'Manage Additional Features'
* for the admin panel. At this page the admin can set preferences
- * for the user settings of the 'additional features'. If needed this
+ * for the user settings of the 'additional features'. If needed this
* preferences can be locked through the admin.
- *
+ *
* The returned string contains the HTML code of the subpage 'Manage
* Additional Features'
- *
+ *
* @param App $a
* @return string
*/
+if(! function_exists('admin_page_features')) {
function admin_page_features(&$a) {
-
+
if((argc() > 1) && (argv(1) === 'features')) {
$arr = array();
$features = get_features(false);
@@ -1933,7 +1966,7 @@ function admin_page_features(&$a) {
);
}
}
-
+
$tpl = get_markup_template("admin_settings_features.tpl");
$o .= replace_macros($tpl, array(
'$form_security_token' => get_form_security_token("admin_manage_features"),
@@ -1945,3 +1978,4 @@ function admin_page_features(&$a) {
return $o;
}
}
+}
diff --git a/mod/allfriends.php b/mod/allfriends.php
index 356a389b8..8843265a9 100644
--- a/mod/allfriends.php
+++ b/mod/allfriends.php
@@ -5,6 +5,7 @@ require_once('include/Contact.php');
require_once('include/contact_selectors.php');
require_once('mod/contacts.php');
+if(! function_exists('allfriends_content')) {
function allfriends_content(&$a) {
$o = '';
@@ -97,3 +98,4 @@ function allfriends_content(&$a) {
return $o;
}
+}
diff --git a/mod/amcd.php b/mod/amcd.php
index a2a1327e6..141a80429 100644
--- a/mod/amcd.php
+++ b/mod/amcd.php
@@ -1,5 +1,5 @@
get_parameters();
$token = $params['oauth_token'];
@@ -19,9 +17,10 @@ function oauth_get_client($request){
return $r[0];
}
+}
+if(! function_exists('api_post')) {
function api_post(&$a) {
-
if(! local_user()) {
notice( t('Permission denied.') . EOL);
return;
@@ -31,9 +30,10 @@ function api_post(&$a) {
notice( t('Permission denied.') . EOL);
return;
}
-
+}
}
+if(! function_exists('api_content')) {
function api_content(&$a) {
if ($a->cmd=='api/oauth/authorize'){
/*
@@ -114,3 +114,4 @@ function api_content(&$a) {
echo api_call($a);
killme();
}
+}
diff --git a/mod/apps.php b/mod/apps.php
index a821ef5d5..e807feae7 100644
--- a/mod/apps.php
+++ b/mod/apps.php
@@ -1,25 +1,23 @@
apps)==0)
+ notice( t('No installed applications.') . EOL);
+
+ $tpl = get_markup_template("apps.tpl");
+ return replace_macros($tpl, array(
+ '$title' => $title,
+ '$apps' => $a->apps,
+ ));
}
-
- $title = t('Applications');
-
- if(count($a->apps)==0)
- notice( t('No installed applications.') . EOL);
-
-
- $tpl = get_markup_template("apps.tpl");
- return replace_macros($tpl, array(
- '$title' => $title,
- '$apps' => $a->apps,
- ));
-
-
-
}
diff --git a/mod/attach.php b/mod/attach.php
index 03f850f0d..849faa26e 100644
--- a/mod/attach.php
+++ b/mod/attach.php
@@ -1,7 +1,7 @@
argc != 2) {
@@ -47,3 +47,4 @@ function attach_init(&$a) {
killme();
// NOTREACHED
}
+}
diff --git a/mod/babel.php b/mod/babel.php
index d31e090c5..56455bdb2 100644
--- a/mod/babel.php
+++ b/mod/babel.php
@@ -9,55 +9,56 @@ function visible_lf($s) {
return str_replace("\n",' ', $s);
}
+if(! function_exists('babel_content')) {
function babel_content(&$a) {
$o .= '
';
- call_hooks('about_hook', $o);
+ call_hooks('about_hook', $o);
return $o;
-
+}
}
diff --git a/mod/fsuggest.php b/mod/fsuggest.php
index 6b1cbd753..26a5e9806 100644
--- a/mod/fsuggest.php
+++ b/mod/fsuggest.php
@@ -1,6 +1,6 @@
';
- $o .= contact_selector('suggest','suggest-select', false,
+ $o .= contact_selector('suggest','suggest-select', false,
array('size' => 4, 'exclude' => $contact_id, 'networks' => 'DFRN_ONLY', 'single' => true));
@@ -109,3 +109,4 @@ function fsuggest_content(&$a) {
return $o;
}
+}
diff --git a/mod/group.php b/mod/group.php
index 5b28784f5..2f8053eef 100644
--- a/mod/group.php
+++ b/mod/group.php
@@ -1,18 +1,21 @@
page['aside'] = group_side('contacts','group','extended',(($a->argc > 1) ? intval($a->argv[1]) : 0));
}
}
+}
-
-
+if(! function_exists('group_post')) {
function group_post(&$a) {
if(! local_user()) {
@@ -64,7 +67,9 @@ function group_post(&$a) {
}
return;
}
+}
+if(! function_exists('group_content')) {
function group_content(&$a) {
$change = false;
@@ -229,5 +234,5 @@ function group_content(&$a) {
}
return replace_macros($tpl, $context);
-
+}
}
diff --git a/mod/hcard.php b/mod/hcard.php
index 6d2d9e2eb..af49423de 100644
--- a/mod/hcard.php
+++ b/mod/hcard.php
@@ -1,5 +1,6 @@
argc > 2) && ($a->argv[2] === 'view')) {
$which = $a->user['nickname'];
- $profile = $a->argv[1];
+ $profile = $a->argv[1];
}
profile_load($a,$which,$profile);
@@ -23,7 +24,7 @@ function hcard_init(&$a) {
if((x($a->profile,'page-flags')) && ($a->profile['page-flags'] == PAGE_COMMUNITY)) {
$a->page['htmlhead'] .= '';
}
- if(x($a->profile,'openidserver'))
+ if(x($a->profile,'openidserver'))
$a->page['htmlhead'] .= '' . "\r\n";
if(x($a->profile,'openid')) {
$delegate = ((strstr($a->profile['openid'],'://')) ? $a->profile['openid'] : 'http://' . $a->profile['openid']);
@@ -42,10 +43,9 @@ function hcard_init(&$a) {
$uri = urlencode('acct:' . $a->profile['nickname'] . '@' . $a->get_hostname() . (($a->path) ? '/' . $a->path : ''));
$a->page['htmlhead'] .= '' . "\r\n";
header('Link: <' . $a->get_baseurl() . '/xrd/?uri=' . $uri . '>; rel="lrdd"; type="application/xrd+xml"', false);
-
+
$dfrn_pages = array('request', 'confirm', 'notify', 'poll');
foreach($dfrn_pages as $dfrn)
$a->page['htmlhead'] .= "get_baseurl()."/dfrn_{$dfrn}/{$which}\" />\r\n";
-
}
-
+}
diff --git a/mod/help.php b/mod/help.php
index 5465d3e90..320e622fa 100644
--- a/mod/help.php
+++ b/mod/help.php
@@ -18,6 +18,7 @@ if (!function_exists('load_doc_file')) {
}
+if(! function_exists('help_content')) {
function help_content(&$a) {
nav_set_selected('help');
@@ -98,5 +99,5 @@ function help_content(&$a) {
}
".$html;
return $html;
-
+}
}
diff --git a/mod/hostxrd.php b/mod/hostxrd.php
index 4121764f1..5b178e9b8 100644
--- a/mod/hostxrd.php
+++ b/mod/hostxrd.php
@@ -2,6 +2,7 @@
require_once('include/crypto.php');
+if(! function_exists('hostxrd_init')) {
function hostxrd_init(&$a) {
header('Access-Control-Allow-Origin: *');
header("Content-type: text/xml");
@@ -27,5 +28,5 @@ function hostxrd_init(&$a) {
));
session_write_close();
exit();
-
+}
}
diff --git a/mod/ignored.php b/mod/ignored.php
index e876b4ef8..8a681a115 100644
--- a/mod/ignored.php
+++ b/mod/ignored.php
@@ -1,6 +1,6 @@
config['system']['theme'] = "../install";
$a->theme['stylesheet'] = $a->get_baseurl()."/view/install/style.css";
-
-
-
+
+
+
global $install_wizard_pass;
if (x($_POST,'pass'))
$install_wizard_pass = intval($_POST['pass']);
-
+}
}
+if(! function_exists('install_post')) {
function install_post(&$a) {
global $install_wizard_pass, $db;
@@ -112,14 +113,18 @@ function install_post(&$a) {
break;
}
}
+}
+if(! function_exists('get_db_errno')) {
function get_db_errno() {
if(class_exists('mysqli'))
return mysqli_connect_errno();
else
return mysql_errno();
}
+}
+if(! function_exists('install_content')) {
function install_content(&$a) {
global $install_wizard_pass, $db;
@@ -304,6 +309,7 @@ function install_content(&$a) {
}
}
+}
/**
* checks : array passed to template
@@ -312,7 +318,8 @@ function install_content(&$a) {
* required : boolean
* help : string optional
*/
-function check_add(&$checks, $title, $status, $required, $help){
+if(! function_exists('check_add')) {
+function check_add(&$checks, $title, $status, $required, $help) {
$checks[] = array(
'title' => $title,
'status' => $status,
@@ -320,7 +327,9 @@ function check_add(&$checks, $title, $status, $required, $help){
'help' => $help,
);
}
+}
+if(! function_exists('check_php')) {
function check_php(&$phpath, &$checks) {
$passed = $passed2 = $passed3 = false;
if (strlen($phpath)){
@@ -370,9 +379,10 @@ function check_php(&$phpath, &$checks) {
check_add($checks, t('PHP register_argc_argv'), $passed3, true, $help);
}
-
+}
}
+if(! function_exists('check_keys')) {
function check_keys(&$checks) {
$help = '';
@@ -392,10 +402,10 @@ function check_keys(&$checks) {
$help .= t('If running under Windows, please see "http://www.php.net/manual/en/openssl.installation.php".');
}
check_add($checks, t('Generate encryption keys'), $res, true, $help);
-
+}
}
-
+if(! function_exists('check_funcs')) {
function check_funcs(&$checks) {
$ck_funcs = array();
check_add($ck_funcs, t('libCurl PHP module'), true, true, "");
@@ -457,8 +467,9 @@ function check_funcs(&$checks) {
/*if((x($_SESSION,'sysmsg')) && is_array($_SESSION['sysmsg']) && count($_SESSION['sysmsg']))
notice( t('Please see the file "INSTALL.txt".') . EOL);*/
}
+}
-
+if(! function_exists('check_htconfig')) {
function check_htconfig(&$checks) {
$status = true;
$help = "";
@@ -473,9 +484,10 @@ function check_htconfig(&$checks) {
}
check_add($checks, t('.htconfig.php is writable'), $status, false, $help);
-
+}
}
+if(! function_exists('check_smarty3')) {
function check_smarty3(&$checks) {
$status = true;
$help = "";
@@ -489,9 +501,10 @@ function check_smarty3(&$checks) {
}
check_add($checks, t('view/smarty3 is writable'), $status, true, $help);
-
+}
}
+if(! function_exists('check_htaccess')) {
function check_htaccess(&$checks) {
$a = get_app();
$status = true;
@@ -511,7 +524,9 @@ function check_htaccess(&$checks) {
// cannot check modrewrite if libcurl is not installed
}
}
+}
+if(! function_exists('check_imagik')) {
function check_imagik(&$checks) {
$imagick = false;
$gif = false;
@@ -528,16 +543,18 @@ function check_imagik(&$checks) {
check_add($checks, t('ImageMagick supports GIF'), $gif, false, "");
}
}
+}
-
-
+if(! function_exists('manual_config')) {
function manual_config(&$a) {
$data = htmlentities($a->data['txt'],ENT_COMPAT,'UTF-8');
$o = t('The database configuration file ".htconfig.php" could not be written. Please use the enclosed text to create a configuration file in your web server root.');
$o .= "";
return $o;
}
+}
+if(! function_exists('load_database_rem')) {
function load_database_rem($v, $i){
$l = trim($i);
if (strlen($l)>1 && ($l[0]=="-" || ($l[0]=="/" && $l[1]=="*"))){
@@ -546,8 +563,9 @@ function load_database_rem($v, $i){
return $v."\n".$i;
}
}
+}
-
+if(! function_exists('load_database')) {
function load_database($db) {
require_once("include/dbstructure.php");
@@ -567,7 +585,9 @@ function load_database($db) {
return $errors;
}
+}
+if(! function_exists('what_next')) {
function what_next() {
$a = get_app();
$baseurl = $a->get_baseurl();
@@ -579,5 +599,4 @@ function what_next() {
.t("Go to your new Friendica node registration page and register as new user. Remember to use the same email you have entered as administrator email. This will allow you to enter the site admin panel.")
."";
}
-
-
+}
diff --git a/mod/invite.php b/mod/invite.php
index ccf876c7c..1f559dabc 100644
--- a/mod/invite.php
+++ b/mod/invite.php
@@ -9,6 +9,7 @@
require_once('include/email.php');
+if(! function_exists('invite_post')) {
function invite_post(&$a) {
if(! local_user()) {
@@ -49,7 +50,7 @@ function invite_post(&$a) {
notice( sprintf( t('%s : Not a valid email address.'), $recip) . EOL);
continue;
}
-
+
if($invonly && ($x || is_site_admin())) {
$code = autoname(8) . srand(1000,9999);
$nmessage = str_replace('$invite_code',$code,$message);
@@ -70,8 +71,8 @@ function invite_post(&$a) {
else
$nmessage = $message;
- $res = mail($recip, email_header_encode( t('Please join us on Friendica'),'UTF-8'),
- $nmessage,
+ $res = mail($recip, email_header_encode( t('Please join us on Friendica'),'UTF-8'),
+ $nmessage,
"From: " . $a->user['email'] . "\n"
. 'Content-type: text/plain; charset=UTF-8' . "\n"
. 'Content-transfer-encoding: 8bit' );
@@ -93,8 +94,9 @@ function invite_post(&$a) {
notice( sprintf( tt("%d message sent.", "%d messages sent.", $total) , $total) . EOL);
return;
}
+}
-
+if(! function_exists('invite_content')) {
function invite_content(&$a) {
if(! local_user()) {
@@ -134,7 +136,7 @@ function invite_content(&$a) {
'$msg_text' => t('Your message:'),
'$default_message' => t('You are cordially invited to join me and other close friends on Friendica - and help us to create a better social web.') . "\r\n" . "\r\n"
. $linktxt
- . "\r\n" . "\r\n" . (($invonly) ? t('You will need to supply this invitation code: $invite_code') . "\r\n" . "\r\n" : '') .t('Once you have registered, please connect with me via my profile page at:')
+ . "\r\n" . "\r\n" . (($invonly) ? t('You will need to supply this invitation code: $invite_code') . "\r\n" . "\r\n" : '') .t('Once you have registered, please connect with me via my profile page at:')
. "\r\n" . "\r\n" . $a->get_baseurl() . '/profile/' . $a->user['nickname']
. "\r\n" . "\r\n" . t('For more information about the Friendica project and why we feel it is important, please visit http://friendica.com') . "\r\n" . "\r\n" ,
'$submit' => t('Submit')
@@ -142,3 +144,4 @@ function invite_content(&$a) {
return $o;
}
+}
diff --git a/mod/item.php b/mod/item.php
index 8c5a47964..f8f2e0faf 100644
--- a/mod/item.php
+++ b/mod/item.php
@@ -25,6 +25,7 @@ require_once('include/text.php');
require_once('include/items.php');
require_once('include/Scrape.php');
+if(! function_exists('item_post')) {
function item_post(&$a) {
if((! local_user()) && (! remote_user()) && (! x($_REQUEST,'commenter')))
@@ -1017,7 +1018,9 @@ function item_post(&$a) {
item_post_return($a->get_baseurl(), $api_source, $return_path);
// NOTREACHED
}
+}
+if(! function_exists('item_post_return')) {
function item_post_return($baseurl, $api_source, $return_path) {
// figure out how to return, depending on from whence we came
@@ -1037,9 +1040,9 @@ function item_post_return($baseurl, $api_source, $return_path) {
echo json_encode($json);
killme();
}
+}
-
-
+if(! function_exists('item_content')) {
function item_content(&$a) {
if((! local_user()) && (! remote_user()))
@@ -1058,6 +1061,7 @@ function item_content(&$a) {
}
return $o;
}
+}
/**
* This function removes the tag $tag from the text $body and replaces it with
@@ -1071,6 +1075,7 @@ function item_content(&$a) {
*
* @return boolean true if replaced, false if not replaced
*/
+if(! function_exists('handle_tag')) {
function handle_tag($a, &$body, &$inform, &$str_tags, $profile_uid, $tag, $network = "") {
require_once("include/Scrape.php");
require_once("include/socgraph.php");
@@ -1245,8 +1250,9 @@ function handle_tag($a, &$body, &$inform, &$str_tags, $profile_uid, $tag, $netwo
return array('replaced' => $replaced, 'contact' => $r[0]);
}
+}
-
+if(! function_exists('store_diaspora_comment_sig')) {
function store_diaspora_comment_sig($datarray, $author, $uprvkey, $parent_item, $post_id) {
// We won't be able to sign Diaspora comments for authenticated visitors - we don't have their private key
@@ -1284,3 +1290,4 @@ function store_diaspora_comment_sig($datarray, $author, $uprvkey, $parent_item,
return;
}
+}
diff --git a/mod/like.php b/mod/like.php
index 8d383b9ab..ef483a1f9 100755
--- a/mod/like.php
+++ b/mod/like.php
@@ -5,6 +5,7 @@ require_once('include/bbcode.php');
require_once('include/items.php');
require_once('include/like.php');
+if(! function_exists('like_content')) {
function like_content(&$a) {
if(! local_user() && ! remote_user()) {
return false;
@@ -28,11 +29,11 @@ function like_content(&$a) {
killme(); // NOTREACHED
// return; // NOTREACHED
}
-
+}
// Decide how to return. If we were called with a 'return' argument,
// then redirect back to the calling page. If not, just quietly end
-
+if(! function_exists('like_content_return')) {
function like_content_return($baseurl, $return_path) {
if($return_path) {
@@ -45,4 +46,4 @@ function like_content_return($baseurl, $return_path) {
killme();
}
-
+}
diff --git a/mod/localtime.php b/mod/localtime.php
index d1453bc52..fc500f4dd 100644
--- a/mod/localtime.php
+++ b/mod/localtime.php
@@ -2,7 +2,7 @@
require_once('include/datetime.php');
-
+if(! function_exists('localtime_post')) {
function localtime_post(&$a) {
$t = $_REQUEST['time'];
@@ -13,9 +13,10 @@ function localtime_post(&$a) {
if($_POST['timezone'])
$a->data['mod-localtime'] = datetime_convert('UTC',$_POST['timezone'],$t,$bd_format);
-
+}
}
+if(! function_exists('localtime_content')) {
function localtime_content(&$a) {
$t = $_REQUEST['time'];
if(! $t)
@@ -38,12 +39,12 @@ function localtime_content(&$a) {
$o .= '';
return $o;
-
-}
\ No newline at end of file
+}
+}
diff --git a/mod/lockview.php b/mod/lockview.php
index 0ae54c8c1..82f93f498 100644
--- a/mod/lockview.php
+++ b/mod/lockview.php
@@ -1,8 +1,8 @@
argc > 1) ? $a->argv[1] : 0);
if (is_numeric($type)) {
$item_id = intval($type);
@@ -10,13 +10,13 @@ function lockview_content(&$a) {
} else {
$item_id = (($a->argc > 2) ? intval($a->argv[2]) : 0);
}
-
+
if(! $item_id)
killme();
if (!in_array($type, array('item','photo','event')))
killme();
-
+
$r = q("SELECT * FROM `%s` WHERE `id` = %d LIMIT 1",
dbesc($type),
intval($item_id)
@@ -33,7 +33,7 @@ function lockview_content(&$a) {
}
- if(($item['private'] == 1) && (! strlen($item['allow_cid'])) && (! strlen($item['allow_gid']))
+ if(($item['private'] == 1) && (! strlen($item['allow_cid'])) && (! strlen($item['allow_gid']))
&& (! strlen($item['deny_cid'])) && (! strlen($item['deny_gid']))) {
echo t('Remote privacy information not available.') . ' ';
@@ -53,7 +53,7 @@ function lockview_content(&$a) {
dbesc(implode(', ', $allowed_groups))
);
if(count($r))
- foreach($r as $rr)
+ foreach($r as $rr)
$l[] = '' . $rr['name'] . '';
}
if(count($allowed_users)) {
@@ -61,7 +61,7 @@ function lockview_content(&$a) {
dbesc(implode(', ',$allowed_users))
);
if(count($r))
- foreach($r as $rr)
+ foreach($r as $rr)
$l[] = $rr['name'];
}
@@ -71,7 +71,7 @@ function lockview_content(&$a) {
dbesc(implode(', ', $deny_groups))
);
if(count($r))
- foreach($r as $rr)
+ foreach($r as $rr)
$l[] = '' . $rr['name'] . '';
}
if(count($deny_users)) {
@@ -79,12 +79,12 @@ function lockview_content(&$a) {
dbesc(implode(', ',$deny_users))
);
if(count($r))
- foreach($r as $rr)
+ foreach($r as $rr)
$l[] = '' . $rr['name'] . '';
}
echo $o . implode(', ', $l);
killme();
-
+}
}
diff --git a/mod/login.php b/mod/login.php
index d09fc1868..47c329eb6 100644
--- a/mod/login.php
+++ b/mod/login.php
@@ -1,5 +1,5 @@
config['register_policy'] == REGISTER_CLOSED) ? false : true);
-
+}
}
diff --git a/mod/lostpass.php b/mod/lostpass.php
index 938d1cbb0..0c4bb1a83 100644
--- a/mod/lostpass.php
+++ b/mod/lostpass.php
@@ -4,6 +4,7 @@ require_once('include/email.php');
require_once('include/enotify.php');
require_once('include/text.php');
+if(! function_exists('lostpass_post')) {
function lostpass_post(&$a) {
$loginame = notags(trim($_POST['login-name']));
@@ -74,10 +75,10 @@ function lostpass_post(&$a) {
'body' => $body));
goaway(z_root());
-
+}
}
-
+if(! function_exists('lostpass_content')) {
function lostpass_content(&$a) {
@@ -164,5 +165,5 @@ function lostpass_content(&$a) {
return $o;
}
-
+}
}
diff --git a/mod/maintenance.php b/mod/maintenance.php
index b50c94c9b..02de29108 100644
--- a/mod/maintenance.php
+++ b/mod/maintenance.php
@@ -1,7 +1,8 @@
t('System down for maintenance')
));
}
+}
diff --git a/mod/manage.php b/mod/manage.php
index adcc3d787..6af3db997 100644
--- a/mod/manage.php
+++ b/mod/manage.php
@@ -2,7 +2,7 @@
require_once("include/text.php");
-
+if(! function_exists('manage_post')) {
function manage_post(&$a) {
if(! local_user())
@@ -87,9 +87,9 @@ function manage_post(&$a) {
goaway( $a->get_baseurl() . "/profile/" . $a->user['nickname'] );
// NOTREACHED
}
+}
-
-
+if(! function_exists('manage_content')) {
function manage_content(&$a) {
if(! local_user()) {
@@ -144,5 +144,5 @@ function manage_content(&$a) {
));
return $o;
-
+}
}
diff --git a/mod/match.php b/mod/match.php
index 3b0367b42..f4936b28d 100644
--- a/mod/match.php
+++ b/mod/match.php
@@ -13,6 +13,7 @@ require_once('mod/proxy.php');
* @param App &$a
* @return void|string
*/
+if(! function_exists('match_content')) {
function match_content(&$a) {
$o = '';
@@ -109,3 +110,4 @@ function match_content(&$a) {
return $o;
}
+}
diff --git a/mod/message.php b/mod/message.php
index 1724ebc42..1f11797d8 100644
--- a/mod/message.php
+++ b/mod/message.php
@@ -3,6 +3,7 @@
require_once('include/acl_selectors.php');
require_once('include/message.php');
+if(! function_exists('message_init')) {
function message_init(&$a) {
$tabs = '';
@@ -36,9 +37,10 @@ function message_init(&$a) {
'$baseurl' => $a->get_baseurl(true),
'$base' => $base
));
-
+}
}
+if(! function_exists('message_post')) {
function message_post(&$a) {
if(! local_user()) {
@@ -91,7 +93,7 @@ function message_post(&$a) {
}
else
goaway($a->get_baseurl(true) . '/' . $_SESSION['return_url']);
-
+}
}
// Note: the code in 'item_extract_images' and 'item_redir_and_replace_images'
@@ -171,7 +173,7 @@ function item_redir_and_replace_images($body, $images, $cid) {
}}
-
+if(! function_exists('message_content')) {
function message_content(&$a) {
$o = '';
@@ -530,7 +532,9 @@ function message_content(&$a) {
return $o;
}
}
+}
+if(! function_exists('get_messages')) {
function get_messages($user, $lstart, $lend) {
return q("SELECT max(`mail`.`created`) AS `mailcreated`, min(`mail`.`seen`) AS `mailseen`,
@@ -541,7 +545,9 @@ function get_messages($user, $lstart, $lend) {
intval($user), intval($lstart), intval($lend)
);
}
+}
+if(! function_exists('render_messages')) {
function render_messages($msg, $t) {
$a = get_app();
@@ -593,3 +599,4 @@ function render_messages($msg, $t) {
return $rslt;
}
+}
diff --git a/mod/modexp.php b/mod/modexp.php
index bba2c2882..282d55a24 100644
--- a/mod/modexp.php
+++ b/mod/modexp.php
@@ -2,6 +2,7 @@
require_once('library/asn1.php');
+if(! function_exists('modexp_init')) {
function modexp_init(&$a) {
if($a->argc != 2)
@@ -29,6 +30,5 @@ function modexp_init(&$a) {
echo 'RSA' . '.' . $m . '.' . $e ;
killme();
-
}
-
+}
diff --git a/mod/mood.php b/mod/mood.php
index eee11e20c..2476f0656 100644
--- a/mod/mood.php
+++ b/mod/mood.php
@@ -4,7 +4,7 @@ require_once('include/security.php');
require_once('include/bbcode.php');
require_once('include/items.php');
-
+if(! function_exists('mood_init')) {
function mood_init(&$a) {
if(! local_user())
@@ -59,7 +59,7 @@ function mood_init(&$a) {
$uri = item_new_uri($a->get_hostname(),$uid);
- $action = sprintf( t('%1$s is currently %2$s'), '[url=' . $poster['url'] . ']' . $poster['name'] . '[/url]' , $verbs[$verb]);
+ $action = sprintf( t('%1$s is currently %2$s'), '[url=' . $poster['url'] . ']' . $poster['name'] . '[/url]' , $verbs[$verb]);
$arr = array();
@@ -105,9 +105,9 @@ function mood_init(&$a) {
return;
}
+}
-
-
+if(! function_exists('mood_content')) {
function mood_content(&$a) {
if(! local_user()) {
@@ -138,5 +138,5 @@ function mood_content(&$a) {
));
return $o;
-
+}
}
diff --git a/mod/msearch.php b/mod/msearch.php
index 89de5b705..3b1b0b617 100644
--- a/mod/msearch.php
+++ b/mod/msearch.php
@@ -1,5 +1,6 @@
$rr['name'],
- 'url' => $a->get_baseurl() . '/profile/' . $rr['nickname'],
+ 'name' => $rr['name'],
+ 'url' => $a->get_baseurl() . '/profile/' . $rr['nickname'],
'photo' => $a->get_baseurl() . '/photo/avatar/' . $rr['uid'] . '.jpg',
'tags' => str_replace(array(',',' '),array(' ',' '),$rr['pub_keywords'])
);
@@ -38,5 +39,5 @@ function msearch_post(&$a) {
echo json_encode($output);
killme();
-
-}
\ No newline at end of file
+}
+}
diff --git a/mod/navigation.php b/mod/navigation.php
index 5db69b171..8fbabfda9 100644
--- a/mod/navigation.php
+++ b/mod/navigation.php
@@ -2,6 +2,7 @@
require_once("include/nav.php");
+if(! function_exists('navigation_content')) {
function navigation_content(&$a) {
$nav_info = nav_info($a);
@@ -22,5 +23,5 @@ function navigation_content(&$a) {
'$apps' => $a->apps,
'$clear_notifs' => t('Clear notifications')
));
-
+}
}
diff --git a/mod/network.php b/mod/network.php
index 0010a3d82..f9a0bec23 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -1,4 +1,6 @@
page['aside'] .= networks_widget($a->get_baseurl(true) . '/network',(x($_GET, 'nets') ? $_GET['nets'] : ''));
$a->page['aside'] .= saved_searches($search);
$a->page['aside'] .= fileas_widget($a->get_baseurl(true) . '/network',(x($_GET, 'file') ? $_GET['file'] : ''));
-
+}
}
+if(! function_exists('saved_searches')) {
function saved_searches($search) {
if(! feature_enabled(local_user(),'savedsearch'))
@@ -204,7 +207,7 @@ function saved_searches($search) {
));
return $o;
-
+}
}
/**
@@ -222,6 +225,7 @@ function saved_searches($search) {
*
* @return Array ( $no_active, $comment_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active, $spam_active );
*/
+if(! function_exists('network_query_get_sel_tab')) {
function network_query_get_sel_tab($a) {
$no_active='';
$starred_active = '';
@@ -278,10 +282,12 @@ function network_query_get_sel_tab($a) {
return array($no_active, $all_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active, $spam_active);
}
+}
/**
* Return selected network from query
*/
+if(! function_exists('network_query_get_sel_net')) {
function network_query_get_sel_net() {
$network = false;
@@ -291,7 +297,9 @@ function network_query_get_sel_net() {
return $network;
}
+}
+if(! function_exists('network_query_get_sel_group')) {
function network_query_get_sel_group($a) {
$group = false;
@@ -301,8 +309,9 @@ function network_query_get_sel_group($a) {
return $group;
}
+}
-
+if(! function_exists('network_content')) {
function network_content(&$a, $update = 0) {
require_once('include/conversation.php');
@@ -886,4 +895,4 @@ function network_content(&$a, $update = 0) {
return $o;
}
-
+}
diff --git a/mod/newmember.php b/mod/newmember.php
index aa55c3a09..ef2533330 100644
--- a/mod/newmember.php
+++ b/mod/newmember.php
@@ -1,5 +1,6 @@
';
- $o .= '
' . '' . t('Friendica Walk-Through') . ' ' . t('On your Quick Start page - find a brief introduction to your profile and network tabs, make some new connections, and find some groups to join.') . '
' . EOL;
+ $o .= '
' . '' . t('Friendica Walk-Through') . ' ' . t('On your Quick Start page - find a brief introduction to your profile and network tabs, make some new connections, and find some groups to join.') . '
' . '' . t('Go to Your Settings') . ' ' . t('On your Settings page - change your initial password. Also make a note of your Identity Address. This looks just like an email address - and will be useful in making friends on the free social web.') . '
' . EOL;
+ $o .= '
' . '' . t('Go to Your Settings') . ' ' . t('On your Settings page - change your initial password. Also make a note of your Identity Address. This looks just like an email address - and will be useful in making friends on the free social web.') . '
' . EOL;
$o .= '
' . t('Review the other settings, particularly the privacy settings. An unpublished directory listing is like having an unlisted phone number. In general, you should probably publish your listing - unless all of your friends and potential friends know exactly how to find you.') . '
' . '' . t('Upload Profile Photo') . ' ' . t('Upload a profile photo if you have not done so already. Studies have shown that people with real photos of themselves are ten times more likely to make friends than people who do not.') . '
' . EOL;
+ $o .= '
' . '' . t('Upload Profile Photo') . ' ' . t('Upload a profile photo if you have not done so already. Studies have shown that people with real photos of themselves are ten times more likely to make friends than people who do not.') . '
' . EOL;
$o .= '
' . '' . t('Edit Your Profile') . ' ' . t('Edit your default profile to your liking. Review the settings for hiding your list of friends and hiding the profile from unknown visitors.') . '
' . '' . t('Importing Emails') . ' ' . t('Enter your email access information on your Connector Settings page if you wish to import and interact with friends or mailing lists from your email INBOX') . '
' . EOL;
@@ -82,3 +83,4 @@ function newmember_content(&$a) {
return $o;
}
+}
diff --git a/mod/nodeinfo.php b/mod/nodeinfo.php
index ba310a105..7f8939182 100644
--- a/mod/nodeinfo.php
+++ b/mod/nodeinfo.php
@@ -1,12 +1,13 @@
diff --git a/mod/nogroup.php b/mod/nogroup.php
index 9f6e97843..818b0da77 100644
--- a/mod/nogroup.php
+++ b/mod/nogroup.php
@@ -4,6 +4,7 @@ require_once('include/Contact.php');
require_once('include/socgraph.php');
require_once('include/contact_selectors.php');
+if(! function_exists('nogroup_init')) {
function nogroup_init(&$a) {
if(! local_user())
@@ -17,8 +18,9 @@ function nogroup_init(&$a) {
$a->page['aside'] .= group_side('contacts','group','extended',0,$contact_id);
}
+}
-
+if(! function_exists('nogroup_content')) {
function nogroup_content(&$a) {
if(! local_user()) {
@@ -66,5 +68,5 @@ function nogroup_content(&$a) {
));
return $o;
-
+}
}
diff --git a/mod/noscrape.php b/mod/noscrape.php
index 51bd7234c..49fe2b9a3 100644
--- a/mod/noscrape.php
+++ b/mod/noscrape.php
@@ -1,5 +1,6 @@
argc > 1)
@@ -62,5 +63,5 @@ function noscrape_init(&$a) {
header('Content-type: application/json; charset=utf-8');
echo json_encode($json_info);
exit;
-
+}
}
diff --git a/mod/notes.php b/mod/notes.php
index 73c1507e3..7817e2554 100644
--- a/mod/notes.php
+++ b/mod/notes.php
@@ -1,5 +1,6 @@
contact['id'] . ">' ";
$r = q("SELECT COUNT(*) AS `total`
FROM `item` LEFT JOIN `contact` ON `contact`.`id` = `item`.`contact-id`
- WHERE `item`.`uid` = %d AND `item`.`visible` = 1 and `item`.`moderated` = 0
+ WHERE `item`.`uid` = %d AND `item`.`visible` = 1 and `item`.`moderated` = 0
AND `item`.`deleted` = 0 AND `item`.`type` = 'note'
AND `contact`.`blocked` = 0 AND `contact`.`pending` = 0 AND `contact`.`self` = 1
AND `item`.`id` = `item`.`parent` AND `item`.`wall` = 0
@@ -90,7 +91,7 @@ function notes_content(&$a,$update = false) {
$r = q("SELECT `item`.`id` AS `item_id`, `contact`.`uid` AS `contact-uid`
FROM `item` LEFT JOIN `contact` ON `contact`.`id` = `item`.`contact-id`
- WHERE `item`.`uid` = %d AND `item`.`visible` = 1 AND `item`.`deleted` = 0
+ WHERE `item`.`uid` = %d AND `item`.`visible` = 1 AND `item`.`deleted` = 0
and `item`.`moderated` = 0 AND `item`.`type` = 'note'
AND `contact`.`blocked` = 0 AND `contact`.`pending` = 0 AND `contact`.`self` = 1
AND `item`.`id` = `item`.`parent` AND `item`.`wall` = 0
@@ -109,10 +110,10 @@ function notes_content(&$a,$update = false) {
foreach($r as $rr)
$parents_arr[] = $rr['item_id'];
$parents_str = implode(', ', $parents_arr);
-
- $r = q("SELECT `item`.*, `item`.`id` AS `item_id`,
- `contact`.`name`, `contact`.`photo`, `contact`.`url`, `contact`.`alias`, `contact`.`network`, `contact`.`rel`,
- `contact`.`thumb`, `contact`.`self`, `contact`.`writable`,
+
+ $r = q("SELECT `item`.*, `item`.`id` AS `item_id`,
+ `contact`.`name`, `contact`.`photo`, `contact`.`url`, `contact`.`alias`, `contact`.`network`, `contact`.`rel`,
+ `contact`.`thumb`, `contact`.`self`, `contact`.`writable`,
`contact`.`id` AS `cid`, `contact`.`uid` AS `contact-uid`
FROM `item` LEFT JOIN `contact` ON `contact`.`id` = `item`.`contact-id`
WHERE `item`.`uid` = %d AND `item`.`visible` = 1 and `item`.`moderated` = 0 AND `item`.`deleted` = 0
@@ -135,3 +136,4 @@ function notes_content(&$a,$update = false) {
$o .= paginate($a);
return $o;
}
+}
diff --git a/mod/notice.php b/mod/notice.php
index 19cf53189..a42d60dd4 100644
--- a/mod/notice.php
+++ b/mod/notice.php
@@ -1,7 +1,8 @@
friendica items permanent-url compatibility */
-
- function notice_init(&$a){
+/* identi.ca -> friendica items permanent-url compatibility */
+
+if(! function_exists('notice_init')) {
+ function notice_init(&$a) {
$id = $a->argv[1];
$r = q("SELECT user.nickname FROM user LEFT JOIN item ON item.uid=user.uid WHERE item.id=%d",
intval($id)
@@ -16,5 +17,5 @@
}
return;
-
}
+}
diff --git a/mod/notifications.php b/mod/notifications.php
index a267b7c95..c7421b2d4 100644
--- a/mod/notifications.php
+++ b/mod/notifications.php
@@ -3,6 +3,7 @@ include_once("include/bbcode.php");
include_once("include/contact_selectors.php");
include_once("include/Scrape.php");
+if(! function_exists('notifications_post')) {
function notifications_post(&$a) {
if(! local_user()) {
@@ -58,11 +59,11 @@ function notifications_post(&$a) {
}
}
}
+}
-
-
+if(! function_exists('notifications_content')) {
function notifications_content(&$a) {
if(! local_user()) {
@@ -579,3 +580,4 @@ function notifications_content(&$a) {
$o .= paginate($a);
return $o;
}
+}
diff --git a/mod/notify.php b/mod/notify.php
index 02260514a..7acac1084 100644
--- a/mod/notify.php
+++ b/mod/notify.php
@@ -1,6 +1,6 @@
query_string, LOGGER_ALL);
if ($a->argv[1]=='b2h'){
@@ -33,3 +34,4 @@ function oembed_content(&$a){
}
killme();
}
+}
diff --git a/mod/oexchange.php b/mod/oexchange.php
index bbb436e70..1e7c9b23c 100644
--- a/mod/oexchange.php
+++ b/mod/oexchange.php
@@ -1,6 +1,6 @@
argc > 1) && ($a->argv[1] === 'xrd')) {
@@ -11,9 +11,10 @@ function oexchange_init(&$a) {
killme();
}
-
+}
}
+if(! function_exists('oexchange_content')) {
function oexchange_content(&$a) {
if(! local_user()) {
@@ -26,13 +27,13 @@ function oexchange_content(&$a) {
return;
}
- $url = (((x($_REQUEST,'url')) && strlen($_REQUEST['url']))
+ $url = (((x($_REQUEST,'url')) && strlen($_REQUEST['url']))
? urlencode(notags(trim($_REQUEST['url']))) : '');
- $title = (((x($_REQUEST,'title')) && strlen($_REQUEST['title']))
+ $title = (((x($_REQUEST,'title')) && strlen($_REQUEST['title']))
? '&title=' . urlencode(notags(trim($_REQUEST['title']))) : '');
- $description = (((x($_REQUEST,'description')) && strlen($_REQUEST['description']))
+ $description = (((x($_REQUEST,'description')) && strlen($_REQUEST['description']))
? '&description=' . urlencode(notags(trim($_REQUEST['description']))) : '');
- $tags = (((x($_REQUEST,'tags')) && strlen($_REQUEST['tags']))
+ $tags = (((x($_REQUEST,'tags')) && strlen($_REQUEST['tags']))
? '&tags=' . urlencode(notags(trim($_REQUEST['tags']))) : '');
$s = fetch_url($a->get_baseurl() . '/parse_url?f=&url=' . $url . $title . $description . $tags);
@@ -52,7 +53,5 @@ function oexchange_content(&$a) {
$_REQUEST = $post;
require_once('mod/item.php');
item_post($a);
-
}
-
-
+}
diff --git a/mod/openid.php b/mod/openid.php
index 5d5539f00..a92a124c0 100644
--- a/mod/openid.php
+++ b/mod/openid.php
@@ -1,9 +1,8 @@
$a->get_baseurl(),
'$nodename' => $a->get_hostname(),
));
-
+
echo $o;
-
+
killme();
-
}
-?>
\ No newline at end of file
+}
+?>
diff --git a/mod/ostatus_subscribe.php b/mod/ostatus_subscribe.php
index 6cca0bf67..a21436db4 100644
--- a/mod/ostatus_subscribe.php
+++ b/mod/ostatus_subscribe.php
@@ -3,6 +3,7 @@
require_once('include/Scrape.php');
require_once('include/follow.php');
+if(! function_exists('ostatus_subscribe_content')) {
function ostatus_subscribe_content(&$a) {
if(! local_user()) {
@@ -76,3 +77,4 @@ function ostatus_subscribe_content(&$a) {
return $o;
}
+}
diff --git a/mod/p.php b/mod/p.php
index 92b72dc1c..225b831fe 100644
--- a/mod/p.php
+++ b/mod/p.php
@@ -4,7 +4,8 @@ This file is part of the Diaspora protocol. It is used for fetching single publi
*/
require_once("include/diaspora.php");
-function p_init($a){
+if(! function_exists('p_init')) {
+function p_init($a) {
if ($a->argc != 2) {
header($_SERVER["SERVER_PROTOCOL"].' 510 '.t('Not Extended'));
killme();
@@ -79,3 +80,4 @@ function p_init($a){
killme();
}
+}
diff --git a/mod/parse_url.php b/mod/parse_url.php
index a1ca5a3db..481cb8936 100644
--- a/mod/parse_url.php
+++ b/mod/parse_url.php
@@ -1,14 +1,14 @@
*
*
- *
+ *
*
*
diff --git a/index.php b/index.php
index bf926d1fe..2b1053cc1 100644
--- a/index.php
+++ b/index.php
@@ -233,7 +233,16 @@ if(strlen($a->module)) {
}
/**
- * If not, next look for a 'standard' program module in the 'mod' directory
+ * If not, next look for module overrides by the theme
+ */
+
+ if((! $a->module_loaded) && (file_exists("view/theme/" . current_theme() . "/mod/{$a->module}.php"))) {
+ include_once("view/theme/" . current_theme() . "/mod/{$a->module}.php");
+ // We will not set module_loaded to true to allow for partial overrides.
+ }
+
+ /**
+ * Finally, look for a 'standard' program module in the 'mod' directory
*/
if((! $a->module_loaded) && (file_exists("mod/{$a->module}.php"))) {